#!/bin/bash
#
# Set Package Info
#
export TLVERSION=5.2.0
export DEBNAME=terralib-wtss-cxx
export DEBVERSION=0.3.0
export DEBARC=amd64
export LIBNAME=Wtss Cxx
export FILENAME=wtss-cxx.tar.gz
export FOLDERNAME=wtss-cxx
export GENERATION_PATH=../../../3rdparty
export DOWNLOAD_LINK=https://github.com/matheuszaglia/wtss.cxx.git
#
# Download Source
#
# if [ ! -d "${FILENAME}" ]; then
#     git clone ${DOWNLOAD_LINK}
# fi

if [ ! -d "${FOLDERNAME}" ]; then
    tar xzvf ${FILENAME}
fi
cd ${FOLDERNAME}
#
# Create debian folder
#
rm -rf debian
mkdir -p debian
#
# Create the copyright file
#
cat > debian/copyright <<EOF
Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
Upstream-Name: TerraLib ${LIBNAME} Library
Upstream-Contact: TerraLib Team <terralib-team@terralib.org>
Source: https://gitlab.dpi.inpe.br/terralib/terralib

Files: *
Copyright: Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil
License: LGPL-3.0
  TerraLib is free software, you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License, or 
  (at your option) any later version.

  TerraLib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU General Public License  
  along with this program. If not, write to TerraLib Team at <terralib-team@terralib.org>.
EOF
#
# Create the changelog (no messages needed)
#
dch --create -v ${DEBVERSION} --distribution unstable --package ${DEBNAME} ""
#
# Create control file
#
cat > debian/control <<EOF
Source: ${DEBNAME}
Maintainer: TerraLib Team <terralib-team@terralib.org>
Section: misc
Priority: optional
Standards-Version: 3.9.2
Build-Depends: debhelper (>= 7)

Package: ${DEBNAME}
Architecture: ${DEBARC}
Depends: \${shlibs:Depends}, \${misc:Depends}, ${DEBNAME} (= ${DEBVERSION})
Description: TerraLib ${LIBNAME} Library, version ${DEBVERSION}
EOF
# 
# Create rules file
#
cat > debian/rules <<EOF 
#!/usr/bin/make -f
%:
	dh \$@
override_dh_auto_configure:
	mkdir -p debian/${DEBNAME}/opt/terralib/${TLVERSION}/3rdparty
	cmake -G "Unix Makefiles" -DCMAKE_PREFIX_PATH:PATH="/opt/terralib/${TLVERSION}/3rdparty/" -DCMAKE_INSTALL_PREFIX:PATH="`pwd`/debian/${DEBNAME}/opt/terralib/${TLVERSION}/3rdparty/" -DCMAKE_INSTALL_RPATH:PATH="`pwd`/debian/${DEBNAME}/opt/terralib/${TLVERSION}/3rdparty/lib" -DCMAKE_SKIP_BUILD_RPATH:BOOL="OFF" -DCMAKE_BUILD_WITH_INSTALL_RPATH:BOOL="OFF" -DCMAKE_INSTALL_RPATH_USE_LINK_PATH:BOOL="ON" -DCMAKE_BUILD_TYPE:STRING="Release" build/cmake
override_dh_auto_build:
	PREFIX=`pwd`/debian/${DEBNAME}/opt/terralib/${TLVERSION}/3rdparty/ make -j 4
override_dh_auto_test:
override_dh_auto_install:
	PREFIX=`pwd`/debian/${DEBNAME}/opt/terralib/${TLVERSION}/3rdparty/ make install -j 4
EOF
#
# Create some misc files
#
echo "8" > debian/compat
mkdir -p debian/source
echo "3.0 (quilt)" > debian/source/format
#
# Build the package
#
# To add a GnuPG key just uncomment the "-k" and change the following key
nice -n19 ionice -c3 debuild -us -uc -b #-kFBC36213
#
# Clean debian-package directory
#
cd ..
if [ -f "${DEBNAME}_${DEBVERSION}_${DEBARC}.deb" ]; then
  rm -rf ${FOLDERNAME} ${FILENAME}
  mkdir -p ${GENERATION_PATH}
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.deb ${GENERATION_PATH}
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.changes ${GENERATION_PATH}
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.build ${GENERATION_PATH}
fi