/*
 * Defining a typemap for std::auto_ptr
 */

%define AUTO_PTR_TYPEMAPS(TYPE...)

%typemap(out) (std::auto_ptr< TYPE >) %{
  SWIG_NewPointerObj(L, (void *) $result.release(), $descriptor(TYPE *), 1); 
  SWIG_arg++;
%}

%template () std::auto_ptr< TYPE >;

%enddef

%define UNIQUE_PTR_TYPEMAPS(TYPE...)

%typemap(out) (std::unique_ptr< TYPE >) %{
  SWIG_NewPointerObj(L, (void *) $result.release(), $descriptor(TYPE *), 1); 
  SWIG_arg++;
%}

%template () std::unique_ptr< TYPE >;

%enddef

namespace std
{
  %template (StrVector) vector <string>;
  %template (StrStrMap) map <string, string>;
}


/*
 * Defining a typemap for std::map< std::string, std::string >
 */

%typemap(in) std::map< std::string, std::string >, const std::map< std::string, std::string > & (std::map< std::string, std::string > aux)
{
  lua_pushnil(L);
  
  while(lua_next(L, -2) != 0)
  {
    if(lua_isstring(L, -1) && lua_isstring(L, -2))
    {
      std::string key(lua_tostring(L, -2)), 
                  value(lua_tostring(L, -1)); 
      
      aux[key] = value;
    }
    
    lua_pop(L, 1);
  }
  
  $1 = &aux;
}

%typemap(out) const std::map< std::string, std::string >&
{
  lua_newtable(L);
  
  std::map<std::string, std::string>::const_iterator it;
    
  for(it = $result->begin(); it != $result->end(); ++it)
  {
    const char* key = it->first.c_str();
    const char* value = it->second.c_str();
    
    lua_pushstring(L, key);
    lua_pushstring(L, value);
    lua_settable(L, -3);
  }
  
  return 1;
}

%typemap(out) std::map< std::string, std::string >
{
  lua_newtable(L);
  
  std::map<std::string, std::string>::const_iterator it;
    
  for(it = $result.begin(); it != $result.end(); ++it)
  {
    const char* key = it->first.c_str();
    const char* value = it->second.c_str();
    
    lua_pushstring(L, key);
    lua_pushstring(L, value);
    lua_settable(L, -3);
  }
  
  return 1;
}

%typemap(out) std::map< std::string, std::string >&
{
  lua_newtable(L);
  
  std::map<std::string, std::string>::const_iterator it;
    
  for(it = $result->begin(); it != $result->end(); ++it)
  {
    const char* key = it->first.c_str();
    const char* value = it->second.c_str();
    
    lua_pushstring(L, key);
    lua_pushstring(L, value);
    lua_settable(L, -3);
  }
  
  return 1;
}

/*
 * Defining a typemap for std::vector< std::string >
 */

%typemap(in) std::vector< std::string >, const std::vector< std::string > & (std::vector< std::string > aux)
{
  lua_pushnil(L);
  
  while(lua_next(L, -2) != 0)
  {
    if(lua_isstring(L, -1))
    {
      std::string value(lua_tostring(L, -1)); 
      aux.push_back(value);
    }
    
    lua_pop(L, 1);
  }
  
  $1 = &aux;
}

%typemap(out) std::vector<std::string>
{
  int s = $result.size();
  lua_createtable(L, s, 0);
  int newTable = lua_gettop(L);
  
  for(int i = 0; i < s; i++)
  {
    lua_pushstring(L, $result[i].c_str());
	lua_rawseti(L, newTable, i);
  }
  
  return 1;
}

namespace std 
{
  template<class T> class auto_ptr { };
  template<class T> class unique_ptr { };
}

/*
 * Defining a typemap for std::vector< te::map::DataSetLayer* >
 */
%typemap(in) std::vector< te::map::DataSetLayer* >, const std::vector< te::map::DataSetLayer* > & (std::vector< te::map::DataSetLayer* > aux)
{
  lua_pushnil(L);
  
  while(lua_next(L, -2) != 0)
  {
    if(lua_isuserdata(L, -1))
    {
	  swig_lua_userdata* usr = (swig_lua_userdata*)lua_touserdata(L, -1);
	  te::map::DataSetLayer* l = (te::map::DataSetLayer*)usr->ptr;  
      aux.push_back(l);
    }
    
    lua_pop(L, 1);
  }
  
  $1 = &aux;
}

%typemap(out) std::vector< te::map::AbstractLayer* >
{
  std::vector<te::map::AbstractLayer*> layers = (std::vector<te::map::AbstractLayer*>)$result;
  int s = layers.size();
  lua_createtable(L, s, 0);
  int newTable = lua_gettop(L);
  
  for(int i = 0; i < s; i++)
  {	
	SWIG_NewPointerObj(L, layers[i], $descriptor(te::map::AbstractLayer*), 0);
	lua_rawseti(L, newTable, i);
  }
  
  return 1;
}