/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
 \file FixGeometry.h
 
 \brief Functrions to fix geometry.
 
 \ingroup vp
 */

#ifndef __TERRALIB_VP_INTERNAL_FIXGEOMETRY_H
#define __TERRALIB_VP_INTERNAL_FIXGEOMETRY_H

//Terralib

#include "../dataaccess/dataset/DataSet.h"
#include "../dataaccess/dataset/DataSetType.h"
#include "../dataaccess/datasource/DataSource.h"
#include "../dataaccess/dataset/ObjectIdSet.h"

#include "../datatype/Property.h"

#include "../geometry/Enums.h"
#include "../memory/DataSet.h"

#include "Algorithm.h"
#include "AlgorithmParams.h"
#include "Config.h"

namespace te
{
  namespace vp
  {

    /*!
      \brief  It tries to fix invalid geometry by SQL clause ST_MakeValid and updates the source data.

      \param dataSource The data source information.
      \param dataSetName The input data name.
      \param errorMessage Variable to catch any error occurred during execution.

      \return True, if the query was executed successfully and the geometries fixed was updated.

      \note The layer must be inserted in a database with spatial extent.
    */
    TEVPEXPORT bool MakeValidGeometry(const te::da::DataSourcePtr dataSource,
                                      const std::string dataSetName,
                                      std::string errorMessage);
  }
}
#endif // __TERRALIB_VP_INTERNAL_DISSOLVE_H
